@@ -1,13 +1,12 @@
 import wget
 import sys
 import os
+from datetime import datetime
 from pepper.modules.python.ImageGenerationUI import UserInterfaceSupport
-from pepper.modules.python.TextColor import TextColor
 
 
 def download_models(output_dir):
     output_dir = UserInterfaceSupport.handle_output_directory(output_dir)
-    sys.stderr.write(TextColor.YELLOW + "DOWNLOADING MODEL DESCRIPTION FILE" + TextColor.END + "\n")
     description_file = "https://storage.googleapis.com/kishwar-helen/models_pepper/pepper_model_description.csv"
     wget.download(description_file, output_dir)
     sys.stderr.write("\n")
@@ -23,8 +22,8 @@ def download_models(output_dir):
         if os.path.exists(output_dir+model_name+".pkl"):
             sys.stderr.write("INFO: MODEL EXISTS " + str(model_name) + ".pkl" + "\n")
             continue
-        sys.stderr.write("INFO: DOWNLOADING FILE: " + str(model_name) + ".pkl\n")
-        sys.stderr.write("INFO: DOWNLOADING LINK: " + str(model_url) + "\n")
+        sys.stderr.write("[" + str(datetime.now().strftime('%m-%d-%Y %H:%M:%S')) + "] INFO: DOWNLOADING FILE: " + str(model_name) + ".pkl\n")
+        sys.stderr.write("[" + str(datetime.now().strftime('%m-%d-%Y %H:%M:%S')) + "] INFO: DOWNLOADING LINK: " + str(model_url) + "\n")
         wget.download(model_url, output_dir)
         sys.stderr.write("\n")
         sys.stderr.flush()
